<div class="row-input">
	<input type="file" data-name="file" data-toggle="webuploader" data-options="
	{
		pick: {lable: 'Upload File'},
        server: '/data/uploadscript',
		fileNumLimit: 1,
        formData:{jid:{{ jid }}},
		required: true
	}
	">
</div>
