pre.prettyprint{border:none; background:transparent;}
.bs-callout {
    padding: 20px;
    margin: 20px 0;
    border: 1px solid #eee;
    border-left-width: 5px;
    border-radius: 3px;
}
.bs-callout+.bs-callout {
    margin-top: -5px;
}
.bs-callout-warning {
    border-left-color: #f0ad4e;
}
.bs-callout-danger {
    border-left-color: #d9534f;
}
.bs-callout-info {
    border-left-color: #5bc0de;
}
.bs-callout h4 {
    margin-top: 0;
    margin-bottom: 5px;
}
.bs-callout-warning h4 {
    color: #f0ad4e;
}
.bs-callout-danger h4 {
    color: #d9534f;
}
.bs-callout-info h4 {
    color: #5bc0de;
}
.bs-callout p:last-child {
    margin-bottom: 0;
}
.bs-callout *:last-child {
    margin-bottom: 0;
}
.bs-example {
    position:relative;
    padding:45px 15px 15px;
    margin:0 -15px 15px;
    border-color:#e5e5e5 #eee #eee;
    border-style:solid;
    border-width:1px 0;
    -webkit-box-shadow:inset 0 3px 6px rgba(0,0,0,.05);
    box-shadow:inset 0 3px 6px rgba(0,0,0,.05)
}
.bs-example:after {
    position:absolute;
    top:15px;
    left:15px;
    font-size:12px;
    font-weight:700;
    color:#959595;
    text-transform:uppercase;
    letter-spacing:1px;
    content:"实例："
}
.bs-example+.highlight,.bs-example+.zero-clipboard+.highlight {
    margin:-15px -15px 15px;
    border-width:0 0 1px;
    border-radius:0
}
@media (min-width:768px) {
    .bs-example {
    margin-right:0;
    margin-left:0;
    background-color:#fff;
    border-color:#ddd;
    border-width:1px;
    border-radius:4px 4px 0 0;
    -webkit-box-shadow:none;
    box-shadow:none
}
.bs-example+.highlight,.bs-example+.zero-clipboard+.highlight {
    margin-top:-16px;
    margin-right:0;
    margin-left:0;
    border-width:1px;
    border-bottom-right-radius:4px;
    border-bottom-left-radius:4px
}
.bs-example-standalone {
    border-radius:4px
}
}.bs-example .container {
    width:auto
}
.bs-example>p:last-child,.bs-example>ul:last-child,.bs-example>ol:last-child,.bs-example>blockquote:last-child,.bs-example>.form-control:last-child,.bs-example>.table:last-child,.bs-example>.navbar:last-child,.bs-example>.jumbotron:last-child,.bs-example>.alert:last-child,.bs-example>.panel:last-child,.bs-example>.list-group:last-child,.bs-example>.well:last-child,.bs-example>.progress:last-child,.bs-example>.table-responsive:last-child>.table {
    margin-bottom:0
}
.bs-example>p>.close {
    float:none
}
.bs-example-type .table .type-info {
    color:#999;
    vertical-align:middle
}
.bs-example-type .table td {
    padding:15px 0;
    border-color:#eee
}
.bs-example-type .table tr:first-child td {
    border-top:0
}
.bs-example-type h1,.bs-example-type h2,.bs-example-type h3,.bs-example-type h4,.bs-example-type h5,.bs-example-type h6 {
    margin:0
}
.bs-example-bg-classes p {
    padding:15px
}
.bs-example>.img-circle,.bs-example>.img-rounded,.bs-example>.img-thumbnail {
    margin:5px
}
.bs-example>.table-responsive>.table {
    background-color:#fff
}
.bs-example>.btn,.bs-example>.btn-group {
    margin-top:5px;
    margin-bottom:5px
}
.bs-example>.btn-toolbar+.btn-toolbar {
    margin-top:10px
}
.bs-example-control-sizing select,.bs-example-control-sizing input[type=text]+input[type=text] {
    margin-top:10px
}
.bs-example-form .input-group {
    margin-bottom:10px
}
.bs-example>textarea.form-control {
    resize:vertical
}
.bs-example>.list-group {
    max-width:400px
}
.bs-example .navbar:last-child {
    margin-bottom:0
}
.zero-clipboard {
    position:relative;
    display:none
}
.btn-clipboard {
    position:absolute;
    top:0;
    right:0;
    z-index:10;
    display:block;
    padding:5px 8px;
    font-size:12px;
    color:#777;
    cursor:pointer;
    background-color:#fff;
    border:1px solid #e1e1e8;
    border-radius:0 4px 0 4px
}
.btn-clipboard-hover {
    color:#fff;
    background-color:#563d7c;
    border-color:#563d7c
}
@media (min-width:768px) {
    .zero-clipboard {
        display:block
    }
    .bs-example+.zero-clipboard .btn-clipboard {
        top:-16px;
        border-top-right-radius:0
    }
}
.highlight {
    padding:9px 14px;
    margin-bottom:14px;
    background-color:#f7f7f9;
    border:1px solid #e1e1e8;
    border-radius:4px
}