/*
Uploadify
Copyright (c) 2012 Reactive Apps, Ronnie Garcia
Released under the MIT License <http://www.opensource.org/licenses/mit-license.php>
*/
.uploadify{position:relative;}
.uploadify-button-text{display:block; font-size:12px; line-height:24px !important;}
.uploadify-button{background-color:#505050;-webkit-border-radius:2px;-moz-border-radius:2px;border-radius:2px;border:1px solid #808080;color:#FFF;text-align:center;width:100%;}
.uploadify-button span{line-height:inherit}
.uploadify:hover .uploadify-button{background-color:#606060;}
.uploadify-button.disabled{background-color:#D0D0D0;color:#808080;}
.uploadify-queue-item{background-color:#F5F5F5;-webkit-border-radius:2px;-moz-border-radius:2px;border-radius:2px;font:11px Verdana, Geneva, sans-serif;margin-top:5px;max-width:350px;padding:10px;}
.uploadify-error{background-color:#FDE5DD !important;}
.uploadify-queue-item .cancel a{background:url('../img/uploadify-cancel.png') 0 0 no-repeat;float:right;height:16px;text-indent:-9999px;width:16px;}
.uploadify-queue-item.completed{background-color:#E5E5E5;}
.uploadify-progress{background-color:#E5E5E5;margin-top:10px;width:100%;}
.uploadify-progress-bar{background-color:#0099FF;height:3px;width:1px;}